---

slug: /utilities-commands
---

# obshell task commands

This topic describes the task commands of obshell, which are used to manage obshell tasks. You can use the `-h`/`--help` option in a command to view the help information of the command. For example, you can run the `obshell task show -h --seekdb` command to view the help information of the `show` command for seekdb. In this command, `--seekdb` indicates that the help information of the `show` command for seekdb is to be viewed.

## obshell task show

You can run this command to view information about a task.

```shell
obshell task show [-i] [-d] [--port] [--seekdb] [-6] [-v]

# example
obshell task show --seekdb --port 2886
```

The following table describes the options.

| Option | Required | Data Type | Default Value | Description |
| --- | --- | --- | --- | --- |
| -i/--id | No | string | N/A | The ID of the task to be viewed. If this option is not specified, the current task is displayed. If no task is being executed, no task information is displayed. |
| -d/--show_detail | No | N/A | N/A | This option does not require a value. If this option is specified, detailed information about the task is displayed. |
| --port | No | int | 2886 | The port number of obshell. If you do not want to specify the port number by using this option, you can specify it by using the environment variable `OBSHELL_PORT_FOR_SEEKDB`. |
| --seekdb | No | N/A | N/A | This option does not require a value. If this option is specified, the command is applied to seekdb. |
|  -6/--use-ipv6 | No | N/A | N/A | This option does not require a value. If this option is specified, IPv6 is used.  |
| -v/--verbose | No | N/A | N/A | This option does not require a value. If this option is specified, detailed execution process information is displayed. |

## obshell task cancel

You can run this command to cancel an uncompleted task.

```shell
obshell task cancel -i [--port] [--seekdb] [-6] [-y]

# example
obshell task cancel -i 11 --seekdb
```

The following table describes the options.

| Option | Required | Data Type | Default Value | Description |
| --- | --- | --- | --- | --- |
| -i/--id | Yes | string | N/A | The ID of the task to be canceled. |
| --port | No | int | 2886 | The port number of obshell. If you do not want to specify the port number by using this option, you can specify it by using the environment variable `OBSHELL_PORT_FOR_SEEKDB`. |
| --seekdb | No | N/A | N/A | This option does not require a value. If this option is specified, the command is applied to seekdb. |
|  -6/--use-ipv6 | No | N/A | N/A | This option does not require a value. If this option is specified, IPv6 is used.  |
| -y/--yes | No | N/A | N/A | This option does not require a value. If this option is specified, the command skips the confirmation. |

## obshell task rollback

You can run this command to roll back a failed task.

```shell
obshell task rollback -i [--port] [--seekdb] [-6] [-y]

# example
obshell task rollback -i 11 --seekdb
```

The following table describes the options.

| Option | Required | Data Type | Default Value | Description |
| --- | --- | --- | --- | --- |
| -i/--id | Yes | string | N/A | The ID of the task to be rolled back. |
| --port | No | int | 2886 | The port number of obshell. If you do not want to specify the port number by using this option, you can specify it by using the environment variable `OBSHELL_PORT_FOR_SEEKDB`. |
| --seekdb | No | N/A | N/A | This option does not require a value. If this option is specified, the command is applied to seekdb. |
|  -6/--use-ipv6 | No | N/A | N/A | This option does not require a value. If this option is specified, IPv6 is used.  |
| -y/--yes | No | N/A | N/A | This option does not require a value. If this option is specified, the command skips the confirmation. |

## obshell task retry

You can run this command to retry a failed task.

```shell
obshell task retry -i [--port] [--seekdb] [-6] [-y]

# example
obshell task retry -i 11 --seekdb
```

The options are described in the following table:

| Option | Required | Data Type | Default Value | Description |
| --- | --- | --- | --- | --- |
| -i/--id | Yes | string | N/A | The ID of the task to be retried. |
| --port | No | int | 2886 | The port number of obshell. If you do not want to specify the port number by using this option, you can also specify it by using the environment variable `OBSHELL_PORT_FOR_SEEKDB`. |
| --seekdb | No | N/A | N/A | This option does not require a value. If you specify this option, the command applies to seekdb. |
|  -6/--use-ipv6 | No | N/A | N/A | This option does not require a value. If you specify this option, IPv6 is used.  |
| -y/--yes | No | N/A | N/A | This option does not require a value. If you specify this option, the command skips the confirmation. |

## obshell task pass

You can run this command to skip a failed task.

```shell
obshell task pass -i [--port] [--seekdb] [-6] [-y]

# example
obshell task pass -i 11 --seekdb
```

The options are described in the following table:

| Option | Required | Data Type | Default Value | Description |
| --- | --- | --- | --- | --- |
| -i/--id | Yes | string | N/A | The ID of the task to be skipped. |
| --port | No | int | 2886 | The port number of obshell. If you do not want to specify the port number by using this option, you can also specify it by using the environment variable `OBSHELL_PORT_FOR_SEEKDB`. |
| --seekdb | No | N/A | N/A | This option does not require a value. If you specify this option, the command applies to seekdb. |
|  -6/--use-ipv6 | No | N/A | N/A | This option does not require a value. If you specify this option, IPv6 is used.  |
| -y/--yes | No | N/A | N/A | This option does not require a value. If you specify this option, the command skips the confirmation. |

## obshell task watch

You can run this command to view the execution progress of a specified task in real time.

```shell
obshell task watch -i [--port] [--seekdb] [-6]

# example
obshell task watch -i 11 --seekdb
```

The options are described in the following table:

| Option | Required | Data Type | Default Value | Description |
| --- | --- | --- | --- | --- |
| -i/--id | Yes | int | N/A | The ID of the running task to be viewed. |
| --port | No | int | 2886 | The port number of obshell. If you do not want to specify the port number by using this option, you can also specify it by using the environment variable `OBSHELL_PORT_FOR_SEEKDB`. |
| --seekdb | No | N/A | N/A | This option does not require a value. If you specify this option, the command applies to seekdb. |
|  -6/--use-ipv6 | No | N/A | N/A | This option does not require a value. If you specify this option, IPv6 is used.  |